[Libreoffice-commits] core.git: starmath/source

Frédéric Wang fred.wang at free.fr
Tue Jul 2 02:07:16 PDT 2013


 starmath/source/mathmlexport.cxx |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 9bb74686b1f857e791235381db632d1b5ac58296
Author: Frédéric Wang <fred.wang at free.fr>
Date:   Sun Jun 30 14:06:23 2013 +0200

     fdo#66088 - follow-up: handle NGLYPHSPECIAL and NSPECIAL too.
    
    Change-Id: Ifc078732e28e9bdaa796c5be3c08c20f9512926e
    Reviewed-on: https://gerrit.libreoffice.org/4631
    Reviewed-by: Bosdonnat Cedric <cedric.bosdonnat at free.fr>
    Tested-by: Bosdonnat Cedric <cedric.bosdonnat at free.fr>

diff --git a/starmath/source/mathmlexport.cxx b/starmath/source/mathmlexport.cxx
index 3fc23b7..a10765e 100644
--- a/starmath/source/mathmlexport.cxx
+++ b/starmath/source/mathmlexport.cxx
@@ -910,9 +910,9 @@ void SmXMLExport::ExportMath(const SmNode *pNode, int /*nLevel*/)
     const SmMathSymbolNode *pTemp = static_cast<const SmMathSymbolNode *>(pNode);
     SvXMLElementExport *pMath = 0;
 
-    if (pNode->GetType() == NMATH)
+    if (pNode->GetType() == NMATH || pNode->GetType() == NGLYPH_SPECIAL)
     {
         // Export NMATH symbols as <mo> elements
         pMath = new SvXMLElementExport(*this, XML_NAMESPACE_MATH, XML_MO, sal_True, sal_False);
     }
     else
@@ -1545,7 +1545,6 @@ void SmXMLExport::ExportNodes(const SmNode *pNode, int nLevel)
         case NTEXT:
             ExportText(pNode, nLevel);
             break;
-        case NSPECIAL: //NSPECIAL requires some sort of Entity preservation in the XML engine.
         case NGLYPH_SPECIAL:
         case NMATH:
             {
@@ -1587,6 +1586,7 @@ void SmXMLExport::ExportNodes(const SmNode *pNode, int nLevel)
                 }
             }
             break;
+        case NSPECIAL: //NSPECIAL requires some sort of Entity preservation in the XML engine.
         case NMATHIDENT :
         case NPLACE:
             ExportMath(pNode, nLevel);
@@ -910,9 +910,9 @@ void SmXMLExport::ExportMath(const SmNode *pNode, int /*nLevel*/)
     {
-        // Export NMATH symbols as <mo> elements
+        // Export NMATH and NGLYPH_SPECIAL symbols as <mo> elements
         pMath = new SvXMLElementExport(*this, XML_NAMESPACE_MATH, XML_MO, sal_True, sal_False);
     }


More information about the Libreoffice-commits mailing list